.. _sun_code_ref:

SunPy sun
*********

The sun submodule contains constants, parameters and models of the Sun.

.. automodapi:: sunpy.sun.constants
   :include-all-objects:

.. automodapi:: sunpy.sun.models
   :include-all-objects:
